"""
MCP Proxy Adapter CLI Entry Point

This module allows running the CLI using: python -m mcp_proxy_adapter

Author: Vasiliy Zdanovskiy
email: vasilyvz@gmail.com
"""

from .cli.main import main

if __name__ == '__main__':
    main()