"""
Author: Vasiliy Zdanovskiy
email: vasilyvz@gmail.com

Authentication manager for security testing.
"""

import base64
from typing import Dict


class AuthManager:
    """Manager for authentication in security testing."""

