"""
MCP Proxy Adapter CLI Module

This module provides command-line interface for MCP Proxy Adapter framework.

Author: Vasiliy Zdanovskiy
email: vasilyvz@gmail.com
"""

from .main import main

__all__ = ['main']
